==> simple_toasts-1.0.x-dev.tar.gz: simple_toasts/src/EventSubscriber/MessagesEventSubscriber.php <==
<?php

namespace Drupal\simple_toasts\EventSubscriber;

use Drupal\simple_toasts\Ajax\SimpleToastsCommand;
use Drupal\Core\Ajax\AjaxResponse;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Event Subscriber MessagesEventSubscriber.
 */
class MessagesEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {

    return [
      KernelEvents::RESPONSE => [['onKernelResponse']],
    ];

  }

  /**
   * Adds the toast messages on the page.
   *
   * @param \Symfony\Component\HttpKernel\Event\ResponseEvent $event
   *   The response event.
   */
  public function onKernelResponse(ResponseEvent $event) {
    $response = $event->getResponse();

    // Using private temp store to get the status messages provided by simple_toasts_preprocess_status_messages.
    $tempstore = \Drupal::service('tempstore.private')->get('simple_toasts');

    // Only for AJAX responses. Cancel if not ajax.
    if (!$response instanceof AjaxResponse) {
      // Delete tempstore variable.
      $tempstore->delete('messages_array');
      return;
    }

    // Array of messages.
    $messagesArray = $tempstore->get('messages_array');

    // Have we set messages to be displayed?
    if (!empty($messagesArray)) {

      // Yes we have messages, so let's call the javascript command function
      // to display them.
      $response->addCommand(
        new SimpleToastsCommand($messagesArray)
      );

      // Delete tempstore variable.
      $tempstore->delete('messages_array');

    }
    $event->setResponse($response);
  }

}

==> simple_toasts-1.1.x-dev.tar.gz: simple_toasts/src/EventSubscriber/MessagesEventSubscriber.php <==
<?php

namespace Drupal\simple_toasts\EventSubscriber;

use Drupal\simple_toasts\Ajax\SimpleToastsCommand;
use Drupal\Core\Ajax\AjaxResponse;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Event Subscriber MessagesEventSubscriber.
 */
class MessagesEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {

    return [
      KernelEvents::RESPONSE => [['onKernelResponse']],
    ];

  }

  /**
   * Adds the toast messages on the page.
   *
   * @param \Symfony\Component\HttpKernel\Event\ResponseEvent $event
   *   The response event.
   */
  public function onKernelResponse(ResponseEvent $event): void {
    $response = $event->getResponse();
    // Using private temp store to get the status messages provided by simple_toasts_preprocess_status_messages.
    $tempstore = \Drupal::service('tempstore.private')->get('simple_toasts');

    // Only for AJAX responses. Cancel if not ajax.
    if (!$response instanceof AjaxResponse) {
      // Delete tempstore variable.
      $tempstore->delete('messages_array');
      return;
    }

    $messagesArray = $tempstore->get('messages_array');

    //Explicitly get any ajax messageCommands and add them to the messagesArray.
    $commands = $response->getCommands();
    foreach ($commands as $command) {

      if ($command['command'] === 'message') {
        $messagesArray[] = [
          'type' => $command['messageOptions']['type'] ?? 'status',
          'message' => $command['message'],
        ];
      }
    }
    if (!empty($messagesArray)) {
      $response->addCommand(
        new SimpleToastsCommand($messagesArray)
      );
      // Delete tempstore variable.
      $tempstore->delete('messages_array');
    }
    $event->setResponse($response);
  }

}
